Skip to contents

Combines the extracted ROXAS / ROXAS AI file names plus data structure (from extract_data_structure()) and ROXAS settings and image exif data (from collect_settings_data()) into a QWAimages object.

Usage

build_QWAimages(df_structure, df_settings)

Arguments

df_structure

Data frame with all input file names and data structure.

df_settings

Data frame with extracted ROXAS (AI) settings data.

Value

A QWAimages object with the joined image-level metadata.

Details

This is the typical starting point of the prepare_rxs_dataset workflow. The resulting QWAimages can be passed directly to collect_raw_data() (to read the cell and ring measurements) and to the metadata Shiny app (launch_metadata_app(), where one can enrich it with site-, tree-, and dataset-level metadata to produce a full QWAmetadata object).