Skip to contents

Runs a series of checks on a QWAimages object and warns about any issues found. Checks include: compliance with the base JSON schema, consistency of the roxas_version attribute with the $software column, missing optional columns, and invalid data structure.

Usage

check_QWAimages(x)

Arguments

x

A QWAimages object.

Value

TRUE, invisibly. Warnings are issued for any problems found; an error is thrown if the object structure is invalid.