Skip to contents

Read and combine data from all cell output files

Usage

collect_cells_data(df_structure)

Arguments

df_structure

Dataframe containing filenames and data structure.

Value

A dataframe with the raw data from all files combined (relevant columns only).