ROXAS does some automatic outlier detection and replaces the found outliers in cell (and ring?) measures by their negative value. This function replaces these 'negatives' with NA.
ROXAS does some automatic outlier detection and replaces the found outliers in cell (and ring?) measures by their negative value. This function replaces these 'negatives' with NA.