Displays a compact overview of a QWAprofile object: the profile type, the number of position bins, and the coverage (images, rings, year range).
Displays a compact overview of a QWAprofile object: the profile type, the number of position bins, and the coverage (images, rings, year range).