Skip to contents

Re-reads the settings/metadata files for the given images and replaces the corresponding rows in the existing QWAimages object. Useful when source files have changed after initial import.

Usage

update_QWAimages(meta, imgs_to_update, settings_date_orders)

Arguments

meta

a QWAimages object

imgs_to_update

character vector of image_label values to update; must be a subset of meta$image_label

settings_date_orders

Character; date order string(s) passed to lubridate::parse_date_time() to parse the rxs_created_at field

Value

An updated QWAimages object