QWAprofile is a subclass of data.frame that holds profiles of QWA
measurements aggregated along the annual rings. Usually elements of the
$profiles slot of a QWAdata object.
Usage
QWAprofile(data, profile_type = c("sector", "band"))Details
Two profile types are supported, set via the profile_type attribute:
"sector": bins defined by equal relative position sectors across the ring width (0–100%).calculate_sector_profiles()"band": bins defined by fixed-width distance bands in microns.calculate_band_profiles()