R/read_rxs_data.R
collect_cells_data.Rd
Read and combine data from all cell output files
collect_cells_data(df_structure)
Dataframe containing filenames and data structure.
A dataframe with the raw data from all files combined (relevant columns only).