Collect the exif data from all image files. Used preliminarily for data generated with classic ROXAS, for ROXAS AI the image exif information is already stored in the settings files.
Arguments
- files_images
Vector/list of image filenames
- batch_size
Nr of images to read exif data from at a time. Note that
exifr::read_exif()is vectorized, so the only purpose for the batching is to generate a progress bar. Increase for more speed.