Read and combine data from all cells and ring output files
Usage
collect_raw_data(df_structure)
Arguments
- df_structure
Dataframe containing filenames and data structure.
Value
QWA_data, i.e. a named list containing the combined raw data
for cells and rings in two dataframes under $cells and $rings, respectively.