Skip to contents

Collect the settings data from all ROXAS (AI) settings files.

Usage

collect_settings_data(files_settings, files_images = NULL, roxas_version)

Arguments

files_settings

Vector of ROXAS settings file names.

files_images

Vector of image file names in the same order as files_settings. Required when roxas_version = "roxas".

roxas_version

The version of ROXAS used to create the files.

Value

A dataframe containing the extracted data.

Details

For roxas_version = "roxas", image EXIF metadata is collected from the image files via collect_image_info() and joined to the settings data. files_images is required in this case and must be in the same order as files_settings.

For roxas_version = "roxas_ai", image metadata is already embedded in the settings JSON files; files_images is not needed.