Function to create coverage plots for all unique treecodes in the provided rings df (usually QWA_data$rings) in a for loop. Plots can be shown and/or saved to a specified path.
Function to create coverage plots for all unique treecodes in the provided rings df (usually QWA_data$rings) in a for loop. Plots can be shown and/or saved to a specified path.