For a single tree, each image covers a span of years. This function allows to visualize which annual rings are covered by which image and which rings have been flagged due to which issues.
For a single tree, each image covers a span of years. This function allows to visualize which annual rings are covered by which image and which rings have been flagged due to which issues.