Update a QWAdata object with re-read raw data for selected images
Source:R/partial_update.R
update_QWAdata.RdRe-reads the raw data files for imgs_to_update, recomputes any derived
cell/ring measures and derived flag columns that are already present in x, and
splices the result back into the existing QWAdata object.
Usage
update_QWAdata(
x,
imgs_to_update,
meta,
exclude_mode = c("either", "incomplete_only"),
reset_manual_flags = TRUE
)Arguments
- x
a QWAdata object
- imgs_to_update
character vector of
image_labelvalues to update; must be a subset ofmeta$image_label- meta
a QWAimages object, required for
complete_flags()when flag columns are present inx- exclude_mode
passed to
complete_flags(); only relevant when the$exclude_issuesflag is present inx: how should the$exclude_issuesflag column be initialized, to exclude any incomplete or missing rings ("either", default) or only the incomplete rings (i.e., not flagging missing/wedging rings for exclusion from analyses,"incomplete_only").- reset_manual_flags
Logical; if
TRUE(default), any manual flag column edits made via the flags Shiny app for the updated images are reset. IfFALSE, existing values in the manual flag columns are kept (i.e. this assumes that the dating was not affected by the re-analysis).
Value
An updated QWAdata object