Re-reads the settings/metadata files for the given images and replaces the corresponding rows in the existing QWAimages object. Useful when source files have changed after initial import.
Arguments
- meta
a QWAimages object
- imgs_to_update
character vector of
image_labelvalues to update; must be a subset ofmeta$image_label- settings_date_orders
Character; date order string(s) passed to
lubridate::parse_date_time()to parse therxs_created_atfield
Value
An updated QWAimages object