Write a QWAimages object to a CSV file.
Arguments
- x
A QWAimages object.
- file
Path to the output file.
- compress
If
TRUE, write compressed.gzfile (defaultFALSE). Note that if you add an compression-related extension to the file name, vroom will automatically compress the output regardless of this parameter.- overwrite
Allow to overwrite existing files? (default
TRUE).
Note
The roxas_version attribute is not written to the CSV file. It is
re-derived from the $software column when the file is read back with
read_QWAimages().